# -*- coding: utf-8 -*-
"""
Created on Wed Mar 29 14:48:22 2023

@author: skiba
"""
###################import data###################
#Most speleothem data is publicly available and should be extracted from the SISALv2 database (https://researchdata.reading.ac.uk/256/) 
#Data from previously unpublished record obtained from stalagite M6_1_57 from Schratten cave, 
#Melchsee-Frutt cave system, Switzerland, can be found in the Supplementary material of the corresponding publication.
#For all other speleothem data please contact Christoph Spötl from the University of Innsbruck: christoph.spoetl@uibk.ac.at

#Alpine Ice Field simulation results are available on zenodo (https://zenodo.org/record/1423176 for Seguinot et al. (2018)
#and https://zenodo.org/records/8270674 for Jouvet et al. (2023), respectively. The simulations should be downloaded and placed 
#in the working directory.
 
import PySimpleGUI as sg
import xarray as xr 
import netCDF4
import scipy
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import cartopy.crs as ccrs
import cartopy.feature as cfeature
import matplotlib as mpl
import scipy.stats as stats
from matplotlib.patches import Rectangle
from mpl_toolkits.axes_grid1 import make_axes_locatable
from mpl_toolkits.mplot3d import Axes3D as ax
import matplotlib.ticker
from matplotlib.ticker import ScalarFormatter, FormatStrFormatter, StrMethodFormatter, MultipleLocator, AutoMinorLocator
from numpy import random
from matplotlib import cm
from matplotlib.colors import ListedColormap, LinearSegmentedColormap
import matplotlib.markers as mmarkers
from matplotlib.patches import Patch
from matplotlib.lines import Line2D
import matplotlib.lines as mlines
from netCDF4 import Dataset
from scipy import interpolate
from scipy.interpolate import RegularGridInterpolator , LinearNDInterpolator
from scipy.signal import butter, lfilter
import matplotlib.colors as clrs
#import os
#os.chdir('C:\\')

def find_nearest(array, value):
    array = np.asarray(array)
    idx = np.nanargmin((np.abs(array - value)))
    return array[idx]

def find_nearestidx(array, value):
    array = np.asarray(array)
    idx = np.nanargmin((np.abs(array - value)))
    return idx

def find_2ndnearestidx(array, value):
    array = np.asarray(array)
    idx = np.argsort(np.abs(array-value))[1]#np.nanargmin((np.abs(array - value)))
    return idx

def find_2ndnearest(array, value):
    array = np.asarray(array)
    idx = np.argsort(np.abs(array-value))[1]#np.nanargmin((np.abs(array - value)))
    return array[idx]

def setdiff_sorted(array1,array2,assume_unique=False):
    ans = np.setdiff1d(array1,array2,assume_unique).tolist()
    if assume_unique:
        return sorted(ans)
    return ans


####################prepare list of cave sites lists###################
##(if more then one record per cave site, this will be a list of arrays of each site)##
#e.g. 
#Spannagel_d13C_all_indiv = [array1_d13C, array2_d13C])
#Spannagel_sampleages_indiv = [array1_ages, array2_ages])
 

####################prepare speleo d13C list including all site lists###################
sampleages_indiv = [Spannagel_sampleages, Baschg_sampleages, SHengste_sampleages, [TKS[:,1]/1000], Hoelloch_sampleages, Schneckenloch_sampleages, [HUN_14[:,0]/1000], Gassel_sampleages, Schratten_sampleages, KlausCramer_sampleages, Beatus_sampleages]
d13C_all_indiv = [Spannagel_d13C_all, Baschg_d13C_all, SHengste_d13C_all,  [TKS[:,2]], Hoelloch_d13C_all, Schneckenloch_d13C_all, [HUN_14[:,2]], Gassel_d13C_all, Schratten_d13C_all,  KlausCramer_d13C_all, Beatus_d13C_all] 
         

cavelats_entities = [47.08, 47.25, 46.75, 47.28, 47.38, 47.33, 47.54, 47.82, 46.78, 47.36, 46.69]
cavelongs_entities = [11.67, 9.67, 7.81, 13.08, 10.15, 9.87, 12.03, 13.84, 8.27, 10.11, 7.78]
cavenames_entities = ["Spannagel", "Baschg", "Sieben Hengste",  "Entrische Kirche", 
                      "Hölloch im Mahdtal", "Schneckenloch", "Grete-Ruth shaft", "Gassel", "Schratten", 
                       'Klaus-Cramer', 'Beatus']
elevation = [2512, 870, 1883, 1040, 1560, 1568, 1491, 1196, 1862,  1964, 1080] 
markerrr = ["*", "v", "^", "<",">","o","d","X","D", "p", "H"]

# Speleothem d13C vs. modelled glacier presence (ice thickness >20 m)

stddd = 2 #ka
stddd_stal = 1#0.2 #ka 
MCs = 1#100

Segmd01pp_agree1_MC = []
Segmd01cp_agree1_MC = []
Seggrippp_agree1_MC = []
Seggripcp_agree1_MC = []
Segepicpp_agree1_MC = []
Segepicpp1km_agree1_MC = []
Segepiccp_agree1_MC = []
Jouvet_agree1_MC = []
    
Segmd01pp_agree2_MC = []
Segmd01cp_agree2_MC = []
Seggrippp_agree2_MC = []
Seggripcp_agree2_MC = []
Segepicpp_agree2_MC = []
Segepicpp1km_agree2_MC = []
Segepiccp_agree2_MC = []
Jouvet_agree2_MC = []
    
Segmd01pp_agree3_MC = []
Segmd01cp_agree3_MC = []
Seggrippp_agree3_MC = []
Seggripcp_agree3_MC = []
Segepicpp_agree3_MC = []
Segepicpp1km_agree3_MC = []
Segepiccp_agree3_MC = []
Jouvet_agree3_MC = []

Segmd01pp_disagree_MC = []
Segmd01cp_disagree_MC = []
Seggrippp_disagree_MC = []
Seggripcp_disagree_MC = []
Segepicpp_disagree_MC = []
Segepicpp1km_disagree_MC = []
Segepiccp_disagree_MC = []
Jouvet_disagree_MC = []

###
simulationsarray = ['alpcyc.2km.md01.pp.ex.1ka.nc', 'alpcyc.2km.md01.cp.ex.1ka.nc', 
                    'alpcyc.2km.grip.pp.ex.1ka.nc', 
                    'alpcyc.2km.grip.cp.ex.1ka.nc', 
                    'alpcyc.2km.epic.pp.ex.1ka.nc', 'alpcyc.1km.epic.pp.ex.1ka.nc', 'alpcyc.2km.epic.cp.ex.1ka.nc', 
                    'ex-AIF-paper.nc']

glacthick = 20#5#20

for v in range(0,MCs):
    sg.one_line_progress_meter('This is my progress meter!', v+1, len(range(0,MCs)), '-key-')
    print(v)
    Segmd01pp_agree1 = []
    Segmd01pp_agree2 = []
    Segmd01pp_agree3 = []
    Segmd01pp_disagree = []
    Segmd01cp_agree1 = []
    Segmd01cp_agree2 = []
    Segmd01cp_agree3 = []
    Segmd01cp_disagree = []
    
    Seggrippp_agree1 = []
    Seggrippp_agree2 = []
    Seggrippp_agree3 = []
    Seggrippp_disagree = []
    Seggripcp_agree1 = []
    Seggripcp_agree2 = []
    Seggripcp_agree3 = []
    Seggripcp_disagree = []
    
    Segepicpp_agree1 = []
    Segepicpp_agree2 = []
    Segepicpp_agree3 = []
    Segepicpp_disagree = []
    Segepicpp1km_agree1 = []
    Segepicpp1km_agree2 = []
    Segepicpp1km_agree3 = []
    Segepicpp1km_disagree = []
    Segepiccp_agree1 = []
    Segepiccp_agree2 = []
    Segepiccp_agree3 = []
    Segepiccp_disagree = []
    
    Jouvet_agree1 = []
    Jouvet_agree2 = []
    Jouvet_agree3 = []
    Jouvet_disagree = []

    for data in simulationsarray: 

        nc    = Dataset(data, 'r')
        time2 = np.squeeze(nc.variables['time'][:])
        time = np.round((time2 / 31536000)/1000, 2) 
        a = np.round(stats.truncnorm((-1000000 - time[-1]) / stddd, (0 - time[-1]) / stddd, loc=time[-1], scale=stddd).rvs(1))
        b = np.round(random.normal(loc=time[0], scale=stddd, size=1))
        n = len(time)
        interval = time[2] - time[1]
        time_new = np.linspace(b,a,n)
        time = time_new[:,0]
        x      = np.squeeze(nc.variables['x'])
        y      = np.squeeze(nc.variables['y'])
        topg = np.squeeze(nc.variables['topg'])            
        thk2 = np.squeeze(nc.variables['thk'])
        thk = np.select([thk2 == -2000000000.0], [0], thk2) 
        nc.close()
        THK = RegularGridInterpolator((time, y, x), thk, bounds_error=False, fill_value=None)
        TOP = RegularGridInterpolator((time, y, x), topg, bounds_error=False, fill_value=None)
        
        icethk_alltimepoints = []
        age_alltimepoints = []
        d13C_alltimepoints = []
    
        agree1 = []
        agree2 = []
        agree3 = []
        disagree = []
        for g in range(0, len(cavelats_entities)):
            ax = plt.subplot(projection=ccrs.UTM(32))
            [handle] = ax.plot(cavelongs_entities[g], cavelats_entities[g], marker='*', color='black', markersize=6, transform=ccrs.Geodetic())
            t_path = handle._get_transformed_path()
            path_in_data_coords, _ = t_path.get_transformed_path_and_affine()
            print(path_in_data_coords.vertices)
            Xval = path_in_data_coords.vertices[0][0]
            Yval = path_in_data_coords.vertices[0][1]
            f = g
            for i in range(0,len(sampleages_indiv[f])):
                a = np.round(random.normal(loc=np.min(sampleages_indiv[f][i]), scale=stddd_stal, size=1))
                b = np.round(random.normal(loc=np.max(sampleages_indiv[f][i]), scale=stddd_stal, size=1))
                n = len(sampleages_indiv[f][i])
                stalage_new = np.linspace(a,b,n)
                stalage = stalage_new[:,0]

                for u in range(0,len(stalage)):            
                    if stalage[u] > 12 and stalage[u] < 115: 
                        pts = (-stalage[u], Yval, Xval)
                        thkkk = THK(pts)
                        icethk_alltimepoints.append(thkkk)
                        age_alltimepoints.append(stalage[u])
                        d13C_alltimepoints.append(d13C_all_indiv[f][i][u])
                        if d13C_all_indiv[f][i][u] < -1 and thkkk <= glacthick:
                            agree1.append(0)
                        elif d13C_all_indiv[f][i][u] < -1 and thkkk > glacthick:
                            disagree.append(0)
                        elif d13C_all_indiv[f][i][u] >= -1 and thkkk > glacthick: 
                            agree2.append(0)
                        elif d13C_all_indiv[f][i][u] >= -1 and thkkk <= glacthick: 
                            agree3.append(0)
                            
        if data == 'C:/Users/skiba/Downloads/alpcyc.2km.md01.cp.ex.1ka.nc':
            Segmd01cp_agree1 = np.array(agree1)
            Segmd01cp_agree2 = np.array(agree2)
            Segmd01cp_agree3 = np.array(agree3)
            Segmd01cp_disagree = np.array(disagree)
        elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.md01.pp.ex.1ka.nc':
            Segmd01pp_agree1 = np.array(agree1)
            Segmd01pp_agree2 = np.array(agree2)
            Segmd01pp_agree3 = np.array(agree3)
            Segmd01pp_disagree = np.array(disagree)
        if data == 'C:/Users/skiba/Downloads/alpcyc.2km.grip.cp.ex.1ka.nc':
            Seggripcp_agree1 = np.array(agree1)
            Seggripcp_agree2 = np.array(agree2)
            Seggripcp_agree3 = np.array(agree3)
            Seggripcp_disagree = np.array(disagree)
        elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.grip.pp.ex.1ka.nc':
            Seggrippp_agree1 = np.array(agree1)
            Seggrippp_agree2 = np.array(agree2)
            Seggrippp_agree3 = np.array(agree3)
            Seggrippp_disagree = np.array(disagree)
        elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.epic.cp.ex.1ka.nc':
            Segepiccp_agree1 = np.array(agree1)
            Segepiccp_agree2 = np.array(agree2)
            Segepiccp_agree3 = np.array(agree3)
            Segepiccp_disagree = np.array(disagree)
        elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.epic.pp.ex.1ka.nc':
            Segepicpp_agree1 = np.array(agree1)
            Segepicpp_agree2 = np.array(agree2)
            Segepicpp_agree3 = np.array(agree3)
            Segepicpp_disagree = np.array(disagree) 
        elif data == 'C:/Users/skiba/Downloads/alpcyc.1km.epic.pp.ex.1ka.nc':
            Segepicpp1km_agree1 = np.array(agree1)
            Segepicpp1km_agree2 = np.array(agree2)
            Segepicpp1km_agree3 = np.array(agree3)
            Segepicpp1km_disagree = np.array(disagree) 
        elif data == 'C:/Users/skiba/Downloads/ex-AIF-paper.nc':
            Jouvet_agree1 = np.array(agree1)
            Jouvet_agree2 = np.array(agree2)
            Jouvet_agree3 = np.array(agree3)
            Jouvet_disagree = np.array(disagree)
   
    Segmd01pp_agree1_MC.append(Segmd01pp_agree1)
    Segmd01cp_agree1_MC.append(Segmd01cp_agree1)
    Seggrippp_agree1_MC.append(Seggrippp_agree1)
    Seggripcp_agree1_MC.append(Seggripcp_agree1)
    Segepicpp_agree1_MC.append(Segepicpp_agree1)
    Segepicpp1km_agree1_MC.append(Segepicpp1km_agree1)
    Segepiccp_agree1_MC.append(Segepiccp_agree1)
    Jouvet_agree1_MC.append(Jouvet_agree1)
    
    Segmd01pp_agree2_MC.append(Segmd01pp_agree2)
    Segmd01cp_agree2_MC.append(Segmd01cp_agree2)
    Seggrippp_agree2_MC.append(Seggrippp_agree2)
    Seggripcp_agree2_MC.append(Seggripcp_agree2)
    Segepicpp_agree2_MC.append(Segepicpp_agree2)
    Segepicpp1km_agree2_MC.append(Segepicpp1km_agree2)
    Segepiccp_agree2_MC.append(Segepiccp_agree2)
    Jouvet_agree2_MC.append(Jouvet_agree2)
    
    Segmd01pp_agree3_MC.append(Segmd01pp_agree3)
    Segmd01cp_agree3_MC.append(Segmd01cp_agree3)
    Seggrippp_agree3_MC.append(Seggrippp_agree3)
    Seggripcp_agree3_MC.append(Seggripcp_agree3)
    Segepicpp_agree3_MC.append(Segepicpp_agree3)
    Segepicpp1km_agree3_MC.append(Segepicpp1km_agree3)
    Segepiccp_agree3_MC.append(Segepiccp_agree3)
    Jouvet_agree3_MC.append(Jouvet_agree3)
    
    Segmd01pp_disagree_MC.append(Segmd01pp_disagree)
    Segmd01cp_disagree_MC.append(Segmd01cp_disagree)
    Seggrippp_disagree_MC.append(Seggrippp_disagree)
    Seggripcp_disagree_MC.append(Seggripcp_disagree)
    Segepicpp_disagree_MC.append(Segepicpp_disagree)
    Segepicpp1km_disagree_MC.append(Segepicpp1km_disagree)
    Segepiccp_disagree_MC.append(Segepiccp_disagree)
    Jouvet_disagree_MC.append(Jouvet_disagree)
   

############make bar plots ##########
#### Age uncertain
all_Segmd01pp_MC = []
all_Segmd01cp_MC = []
all_Seggrippp_MC = []
all_Seggripcp_MC = []
all_Segepicpp_MC = []
all_Segepicpp1km_MC = []
all_Segepiccp_MC = []
all_Jouvet_MC = []

Segmd01pp_perc_MC_agree1 = []
Segmd01cp_perc_MC_agree1 = []
Seggrippp_perc_MC_agree1 = []
Seggripcp_perc_MC_agree1 = []
Segepicpp_perc_MC_agree1 = []
Segepicpp1km_perc_MC_agree1 = []
Segepiccp_perc_MC_agree1 = []
Jouvet_perc_MC_agree1 = []

Segmd01pp_perc_MC_agree2 = []
Segmd01cp_perc_MC_agree2 = []
Seggrippp_perc_MC_agree2 = []
Seggripcp_perc_MC_agree2 = []
Segepicpp_perc_MC_agree2 = []
Segepicpp1km_perc_MC_agree2 = []
Segepiccp_perc_MC_agree2 = []
Jouvet_perc_MC_agree2 = []

Segmd01pp_perc_MC_agree3 = []
Segmd01cp_perc_MC_agree3 = []
Seggrippp_perc_MC_agree3 = []
Seggripcp_perc_MC_agree3 = []
Segepicpp_perc_MC_agree3 = []
Segepicpp1km_perc_MC_agree3 = []
Segepiccp_perc_MC_agree3 = []
Jouvet_perc_MC_agree3 = []

Segmd01pp_perc_MC_disagree = []
Segmd01cp_perc_MC_disagree = []
Seggrippp_perc_MC_disagree = []
Seggripcp_perc_MC_disagree = []
Segepicpp_perc_MC_disagree = []
Segepicpp1km_perc_MC_disagree = []
Segepiccp_perc_MC_disagree = []
Jouvet_perc_MC_disagree = []

for g in range(0, MCs):
    # Calculate sample size
    A = len(np.hstack([np.array(Segmd01pp_agree1_MC[g]), np.array(Segmd01pp_agree2_MC[g]), np.array(Segmd01pp_agree3_MC[g]), np.array(Segmd01pp_disagree_MC[g])]))
    B = len(np.hstack([np.array(Segmd01cp_agree1_MC[g]), np.array(Segmd01cp_agree2_MC[g]), np.array(Segmd01cp_agree3_MC[g]), np.array(Segmd01cp_disagree_MC[g])]))
    C = len(np.hstack([np.array(Seggrippp_agree1_MC[g]), np.array(Seggrippp_agree2_MC[g]), np.array(Seggrippp_agree3_MC[g]), np.array(Seggrippp_disagree_MC[g])]))
    D = len(np.hstack([np.array(Seggripcp_agree1_MC[g]), np.array(Seggripcp_agree2_MC[g]), np.array(Seggripcp_agree3_MC[g]), np.array(Seggripcp_disagree_MC[g])]))
    E = len(np.hstack([np.array(Segepicpp_agree1_MC[g]), np.array(Segepicpp_agree2_MC[g]), np.array(Segepicpp_agree3_MC[g]), np.array(Segepicpp_disagree_MC[g])]))
    F = len(np.hstack([np.array(Segepiccp_agree1_MC[g]), np.array(Segepiccp_agree2_MC[g]), np.array(Segepiccp_agree3_MC[g]), np.array(Segepiccp_disagree_MC[g])]))
    G = len(np.hstack([np.array(Jouvet_agree1_MC[g]), np.array(Jouvet_agree2_MC[g]), np.array(Jouvet_agree3_MC[g]), np.array(Jouvet_disagree_MC[g])]))   
    H = len(np.hstack([np.array(Segepicpp1km_agree1_MC[g]), np.array(Segepicpp1km_agree2_MC[g]), np.array(Segepicpp1km_agree3_MC[g]), np.array(Segepicpp1km_disagree_MC[g])]))
    
    all_Segmd01pp_MC.append(A)
    all_Segmd01cp_MC.append(B)
    all_Seggrippp_MC.append(C)
    all_Seggripcp_MC.append(D)
    all_Segepicpp_MC.append(E)
    all_Segepiccp_MC.append(F)   
    all_Jouvet_MC.append(G)   
    all_Segepicpp1km_MC.append(H)
    
    # Calculate percentage in each group
    Segmd01pp_perc_MC_agree1.append(len(Segmd01pp_agree1_MC[g])/A*100)
    Segmd01cp_perc_MC_agree1.append(len(Segmd01cp_agree1_MC[g])/B*100)
    Seggrippp_perc_MC_agree1.append(len(Seggrippp_agree1_MC[g])/C*100)
    Seggripcp_perc_MC_agree1.append(len(Seggripcp_agree1_MC[g])/D*100)
    Segepicpp_perc_MC_agree1.append(len(Segepicpp_agree1_MC[g])/E*100)
    Segepicpp1km_perc_MC_agree1.append(len(Segepicpp1km_agree1_MC[g])/H*100)
    Segepiccp_perc_MC_agree1.append(len(Segepiccp_agree1_MC[g])/F*100)
    Jouvet_perc_MC_agree1.append(len(Jouvet_agree1_MC[g])/G*100)
    
    Segmd01pp_perc_MC_agree2.append(len(Segmd01pp_agree2_MC[g])/A*100)
    Segmd01cp_perc_MC_agree2.append(len(Segmd01cp_agree2_MC[g])/B*100)
    Seggrippp_perc_MC_agree2.append(len(Seggrippp_agree2_MC[g])/C*100)
    Seggripcp_perc_MC_agree2.append(len(Seggripcp_agree2_MC[g])/D*100)
    Segepicpp_perc_MC_agree2.append(len(Segepicpp_agree2_MC[g])/E*100)
    Segepicpp1km_perc_MC_agree2.append(len(Segepicpp1km_agree2_MC[g])/H*100)
    Segepiccp_perc_MC_agree2.append(len(Segepiccp_agree2_MC[g])/F*100)
    Jouvet_perc_MC_agree2.append(len(Jouvet_agree2_MC[g])/G*100)
    
    Segmd01pp_perc_MC_agree3.append(len(Segmd01pp_agree3_MC[g])/A*100)
    Segmd01cp_perc_MC_agree3.append(len(Segmd01cp_agree3_MC[g])/B*100)
    Seggrippp_perc_MC_agree3.append(len(Seggrippp_agree3_MC[g])/C*100)
    Seggripcp_perc_MC_agree3.append(len(Seggripcp_agree3_MC[g])/D*100)
    Segepicpp_perc_MC_agree3.append(len(Segepicpp_agree3_MC[g])/E*100)
    Segepicpp1km_perc_MC_agree3.append(len(Segepicpp1km_agree3_MC[g])/H*100)
    Segepiccp_perc_MC_agree3.append(len(Segepiccp_agree3_MC[g])/F*100)
    Jouvet_perc_MC_agree3.append(len(Jouvet_agree3_MC[g])/G*100)

    Segmd01pp_perc_MC_disagree.append(len(Segmd01pp_disagree_MC[g])/A*100)
    Segmd01cp_perc_MC_disagree.append(len(Segmd01cp_disagree_MC[g])/B*100)
    Seggrippp_perc_MC_disagree.append(len(Seggrippp_disagree_MC[g])/C*100)
    Seggripcp_perc_MC_disagree.append(len(Seggripcp_disagree_MC[g])/D*100)
    Segepicpp_perc_MC_disagree.append(len(Segepicpp_disagree_MC[g])/E*100)
    Segepicpp1km_perc_MC_disagree.append(len(Segepicpp1km_disagree_MC[g])/H*100)
    Segepiccp_perc_MC_disagree.append(len(Segepiccp_disagree_MC[g])/F*100)
    Jouvet_perc_MC_disagree.append(len(Jouvet_disagree_MC[g])/G*100)  
    
    
# Mean and standard dev of percentage in each group
Segmd01pp_agree1_mean = np.mean(Segmd01pp_perc_MC_agree1)
Segmd01pp_agree2_mean = np.mean(Segmd01pp_perc_MC_agree2)
Segmd01pp_agree3_mean = np.mean(Segmd01pp_perc_MC_agree3)
Segmd01pp_disagree_mean = np.mean(Segmd01pp_perc_MC_disagree)
Segmd01cp_agree1_mean = np.mean(Segmd01cp_perc_MC_agree1)
Segmd01cp_agree2_mean = np.mean(Segmd01cp_perc_MC_agree2)
Segmd01cp_agree3_mean = np.mean(Segmd01cp_perc_MC_agree3)
Segmd01cp_disagree_mean = np.mean(Segmd01cp_perc_MC_disagree)
Seggrippp_agree1_mean = np.mean(Seggrippp_perc_MC_agree1)
Seggrippp_agree2_mean = np.mean(Seggrippp_perc_MC_agree2)
Seggrippp_agree3_mean = np.mean(Seggrippp_perc_MC_agree3)
Seggrippp_disagree_mean = np.mean(Seggrippp_perc_MC_disagree)
Seggripcp_agree1_mean = np.mean(Seggripcp_perc_MC_agree1)
Seggripcp_agree2_mean = np.mean(Seggripcp_perc_MC_agree2)
Seggripcp_agree3_mean = np.mean(Seggripcp_perc_MC_agree3)
Seggripcp_disagree_mean = np.mean(Seggripcp_perc_MC_disagree) 
Segepicpp_agree1_mean = np.mean(Segepicpp_perc_MC_agree1)
Segepicpp_agree2_mean = np.mean(Segepicpp_perc_MC_agree2)
Segepicpp_agree3_mean = np.mean(Segepicpp_perc_MC_agree3)
Segepicpp_disagree_mean = np.mean(Segepicpp_perc_MC_disagree)
Segepicpp1km_agree1_mean = np.mean(Segepicpp1km_perc_MC_agree1)
Segepicpp1km_agree2_mean = np.mean(Segepicpp1km_perc_MC_agree2)
Segepicpp1km_agree3_mean = np.mean(Segepicpp1km_perc_MC_agree3)
Segepicpp1km_disagree_mean = np.mean(Segepicpp1km_perc_MC_disagree)
Segepiccp_agree1_mean = np.mean(Segepiccp_perc_MC_agree1)
Segepiccp_agree2_mean = np.mean(Segepiccp_perc_MC_agree2)
Segepiccp_agree3_mean = np.mean(Segepiccp_perc_MC_agree3)
Segepiccp_disagree_mean = np.mean(Segepiccp_perc_MC_disagree) 
Jouvet_agree1_mean = np.mean(Jouvet_perc_MC_agree1)
Jouvet_agree2_mean = np.mean(Jouvet_perc_MC_agree2)
Jouvet_agree3_mean = np.mean(Jouvet_perc_MC_agree3)
Jouvet_disagree_mean = np.mean(Jouvet_perc_MC_disagree) 

Segmd01pp_agree1_std = np.std(Segmd01pp_perc_MC_agree1)
Segmd01pp_agree2_std = np.std(Segmd01pp_perc_MC_agree2)
Segmd01pp_agree3_std = np.std(Segmd01pp_perc_MC_agree3)
Segmd01pp_disagree_std = np.std(Segmd01pp_perc_MC_disagree)
Segmd01cp_agree1_std = np.std(Segmd01cp_perc_MC_agree1)
Segmd01cp_agree2_std = np.std(Segmd01cp_perc_MC_agree2)
Segmd01cp_agree3_std = np.std(Segmd01cp_perc_MC_agree3)
Segmd01cp_disagree_std = np.std(Segmd01cp_perc_MC_disagree)
Seggrippp_agree1_std = np.std(Seggrippp_perc_MC_agree1)
Seggrippp_agree2_std = np.std(Seggrippp_perc_MC_agree2)
Seggrippp_agree3_std = np.std(Seggrippp_perc_MC_agree3)
Seggrippp_disagree_std = np.std(Seggrippp_perc_MC_disagree)
Seggripcp_agree1_std = np.std(Seggripcp_perc_MC_agree1)
Seggripcp_agree2_std = np.std(Seggripcp_perc_MC_agree2)
Seggripcp_agree3_std = np.std(Seggripcp_perc_MC_agree3)
Seggripcp_disagree_std = np.std(Seggripcp_perc_MC_disagree) 
Segepicpp_agree1_std = np.std(Segepicpp_perc_MC_agree1)
Segepicpp_agree2_std = np.std(Segepicpp_perc_MC_agree2)
Segepicpp_agree3_std = np.std(Segepicpp_perc_MC_agree3)
Segepicpp_disagree_std = np.std(Segepicpp_perc_MC_disagree)
Segepicpp1km_agree1_std = np.std(Segepicpp1km_perc_MC_agree1)
Segepicpp1km_agree2_std = np.std(Segepicpp1km_perc_MC_agree2)
Segepicpp1km_agree3_std = np.std(Segepicpp1km_perc_MC_agree3)
Segepicpp1km_disagree_std = np.std(Segepicpp1km_perc_MC_disagree)
Segepiccp_agree1_std = np.std(Segepiccp_perc_MC_agree1)
Segepiccp_agree2_std = np.std(Segepiccp_perc_MC_agree2)
Segepiccp_agree3_std = np.std(Segepiccp_perc_MC_agree3)
Segepiccp_disagree_std = np.std(Segepiccp_perc_MC_disagree) 
Jouvet_agree1_std = np.std(Jouvet_perc_MC_agree1)
Jouvet_agree2_std = np.std(Jouvet_perc_MC_agree2)
Jouvet_agree3_std = np.std(Jouvet_perc_MC_agree3)
Jouvet_disagree_std = np.std(Jouvet_perc_MC_disagree) 


factor = 2 #set to 1 if only 1 sigma should be shown as error bar
fig = plt.subplots(figsize=(10,8.5))
# Set width of bars
barWidth = 0.1
space = 0.005
# Produce colour scheme 
clor = clrs.ListedColormap(['#1b9e77', '#7EF2C7','#d95f02', '#FFB05C', '#7570b3', '#ABA4EB', '#E3DBFF', '#282A65'])

# Set position of bar on X axis
r1 =  np.arange(4)
r2 = [x + barWidth + space for x in r1]
r3 = [x + barWidth + space for x in r2]
r4 = [x + barWidth + space for x in r3]
r5 = [x + barWidth + space for x in r4]
r6 = [x + barWidth + space for x in r5]
r7 = [x + barWidth + space for x in r6]
r8 = [x + barWidth + space for x in r7]
   
# Make the plot
plt.bar(r1, [Segmd01cp_agree1_mean, Segmd01cp_agree2_mean, Segmd01cp_agree3_mean, Segmd01cp_disagree_mean], yerr= [factor*Segmd01cp_agree1_std, factor*Segmd01cp_agree2_std, factor*Segmd01cp_agree3_std, factor*Segmd01cp_disagree_std], align='center', capsize=10, color=clor(0), hatch='/', width=barWidth, edgecolor='white', label='Seguinot et al., Iberian Margin, cp')
plt.bar(r2, [Segmd01pp_agree1_mean, Segmd01pp_agree2_mean, Segmd01pp_agree3_mean, Segmd01pp_disagree_mean], yerr = [factor*Segmd01pp_agree1_std, factor*Segmd01pp_agree2_std, factor*Segmd01pp_agree3_std, factor*Segmd01pp_disagree_std], align='center', capsize=10, color=clor(1), hatch='/', width=barWidth, edgecolor='white', label='Seguinot et al., Iberian Margin, pp')
plt.bar(r3, [Seggripcp_agree1_mean, Seggripcp_agree2_mean, Seggripcp_agree3_mean, Seggripcp_disagree_mean], yerr= [factor*Seggripcp_agree1_std, factor*Seggripcp_agree2_std, factor*Seggripcp_agree3_std, factor*Seggripcp_disagree_std],  align='center', capsize=10,color=clor(2), hatch='+', width=barWidth, edgecolor='white', label='Seguinot et al., GRIP, cp')
plt.bar(r4, [Seggrippp_agree1_mean, Seggrippp_agree2_mean, Seggrippp_agree3_mean, Seggrippp_disagree_mean], yerr= [factor*Seggrippp_agree1_std, factor*Seggrippp_agree2_std, factor*Seggrippp_agree3_std, factor*Seggrippp_disagree_std], align='center', capsize=10,color=clor(3), hatch='+', width=barWidth, edgecolor='white', label='Seguinot et al., GRIP, pp')
plt.bar(r5, [Segepiccp_agree1_mean, Segepiccp_agree2_mean, Segepiccp_agree3_mean, Segepiccp_disagree_mean], yerr= [factor*Segepiccp_agree1_std, factor*Segepiccp_agree2_std, factor*Segepiccp_agree3_std, factor*Segepiccp_disagree_std], align='center', capsize=10,color=clor(4), hatch='o', width=barWidth, edgecolor='white', label='Seguinot et al., EPICA, cp')
plt.bar(r6, [Segepicpp_agree1_mean, Segepicpp_agree2_mean, Segepicpp_agree3_mean, Segepicpp_disagree_mean], yerr = [factor*Segepicpp_agree1_std, factor*Segepicpp_agree2_std, factor*Segepicpp_agree3_std, factor*Segepicpp_disagree_std], align='center', capsize=10,color=clor(5), hatch='o', width=barWidth, edgecolor='white', label='Seguinot et al., EPICA, pp')#
plt.bar(r7, [Segepicpp1km_agree1_mean, Segepicpp1km_agree2_mean, Segepicpp1km_agree3_mean, Segepicpp1km_disagree_mean], yerr = [factor*Segepicpp1km_agree1_std, factor*Segepicpp1km_agree2_std, factor*Segepicpp1km_agree3_std, factor*Segepicpp1km_disagree_std], align='center', capsize=10, color=clor(6), hatch='o', width=barWidth, edgecolor='white', label='Seguinot et al., EPICA, pp, 1 km')
plt.bar(r8, [Jouvet_agree1_mean, Jouvet_agree2_mean, Jouvet_agree3_mean, Jouvet_disagree_mean], yerr= [factor*Jouvet_agree1_std, factor*Jouvet_agree2_std, factor*Jouvet_agree3_std, factor*Jouvet_disagree_std], align='center', capsize=10, color=clor(7), hatch='o', width=barWidth, edgecolor='white', label='Jouvet et al., EPICA')
   
# Add xticks on the middle of the group bars
plt.xticks(r4, ['Agreement #1', 'Agreement #2', 'Agreement #3', 'Disagreement'], fontsize = 16)
plt.ylabel("Percentage of data points [%]", fontsize =18, weight="bold", labelpad=10)
plt.ylim(0,80)
plt.yticks(fontsize=18)

# Create legend 
leg = plt.legend(prop={'size': 13}, loc="upper left",ncol=2)
leg.set_title('Simulation',prop={'size':16, 'weight':"bold"})
#plt.title("Ice thickness > 5 m", fontsize=16, weight="bold")
#plt.show()
 
plt.savefig("paper/NorthAlpsSpeleo_d13Cvsicethk_icethick20m_wGRIP_only12to115ka_interp_20230907_w1km_ageuncertstrati100MC.png", dpi=350, bbox_inches = 'tight')       
